#!/usr/bin/env python
import argparse

from twitter_timeline_rss.twitter import feed, home


parser = argparse.ArgumentParser(description='Dump twitter RSS feeds')
parser.add_argument('--user', help='User from which to ingest timeline')
parser.add_argument('--file', help='Dump to specified file instead of stdout')
args = parser.parse_args()


def main():
    response_object = feed(args.user) if args.user else home()
    response_text = response_object.response
    if isinstance(response_text, list):
        response_text = b''.join(response_text)
    if args.file:
        with open(args.file, 'w') as f:
            f.write(response_text)
    else:
        print(response_text)



from setuptools import setup, find_packages
from twitter_timeline_rss import __version__ as version


setup(
    name='twitter-timeline-rss',
    version=version,
    description=('Ingest a twitter timeline and render as RSS'),
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules'],
    keywords='twitter timeline rss atom flask',
    author='Jon Robison',
    author_email='narfman0@gmail.com',
    url='https://github.com/narfman0/twitter-timeline-rss',
    license='LICENSE',
    packages=find_packages(),
    include_package_data=True,
    zip_safe=True,
    install_requires=['tweepy', 'flask'],
    tests_require=['tox', 'coverage', 'flake8', 'wheel'],
    test_suite='tests',
    entry_points={
        'console_scripts': ['twitter_timeline_rss=twitter_timeline_rss.cli:main'],
    }
)



import os

TWITTER_CONSUMER_KEY = os.environ.get('TWITTER_CONSUMER_KEY', '')
TWITTER_CONSUMER_SECRET = os.environ.get('TWITTER_CONSUMER_SECRET', '')
TWITTER_ACCESS_TOKEN = os.environ.get('TWITTER_ACCESS_TOKEN', '')
TWITTER_ACCESS_TOKEN_SECRET = os.environ.get('TWITTER_ACCESS_TOKEN_SECRET', '')
